@@ -23,6 +23,9 @@ fn main() -> Result<()> {
         .exec()?;
     println!("{:#?}", c3);
 
+    let c4 = Command::new("git ls-remote https://gitlab.com/crates-rs/reef.git HEAD").exec()?;
+    println!("{:#?}", c4);
+
     let rake_dir = std::env::temp_dir().join("reef.command.rake");
     if !rake_dir.exists() {
         std::fs::create_dir_all(&rake_dir)?;
