@@ -22,12 +22,27 @@ pub struct Command {
     exit_code: Option<i32>,
     duration: Option<Duration>,
     start: Option<DateTime<Utc>>,
+    user: String,
+    machine: String,
+    os: String,
 }
 
 impl Command {
     pub fn new(name: &str) -> Self {
         let mut d = Command::default();
-        d.name = name.to_string();
+        let parts: Vec<&str> = name.trim().split_whitespace().collect();
+        let mut index = 0;
+        for part in parts {
+            if index == 0 {
+                d.name = part.to_string();
+            } else {
+                d.arg(part);
+            }
+            index += 1;
+        }
+        d.user = whoami::username();
+        d.machine = whoami::hostname();
+        d.os = whoami::distro();
         d
     }
 
@@ -47,6 +62,7 @@ impl Command {
     }
 
     fn output(&mut self) -> Result<std::process::Output> {
+        // TODO: restore current_dir is it changed
         match self.timeout {
             Some(timeout) => {
                 let mut cmd = std::process::Command::new(&self.exe_filename);
@@ -112,6 +128,9 @@ impl Command {
                 timeout: self.timeout,
                 timed_out: self.timed_out,
                 start: Some(start),
+                user: whoami::username(),
+                machine: whoami::hostname(),
+                os: whoami::distro(),
             };
             Storage::add(&command)?;
             Ok(command)
@@ -202,6 +221,17 @@ impl Command {
         }
     }
 
+    pub fn user(&self) -> &str {
+        &self.user
+    }
+
+    pub fn machine(&self) -> &str {
+        &self.machine
+    }
+
+    pub fn os(&self) -> &str {
+        &self.os
+    }
     pub fn collect(search: &str, limit: usize) -> Result<Vec<Command>> {
         Storage::search(search, limit)
             .with_context(|| format!("Command::collect('{}',{})", search, limit))
